@@ -6,7 +6,7 @@ use strict;
 use POSIX qw(strftime);
 use Time::Local;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 my $LAX_DATE_RE  = qr<[0-9]{4}[-/](?:0[1-9]|1[0-2])[-/](?:0[1-9]|[12][0-9]|3[01])>;
 my $TIME_RE      = qr<(?:[01][0-9]|2[0-3]):[0-5][0-9]:[0-6][0-9]>;
@@ -47,7 +47,7 @@ sub fmt_date
 sub is_today
 {
     my ($day) = @_;
-    return (!$day or $day eq $TODAY);
+    return (!$day or $day eq $TODAY or $day eq today_stamp());
 }
 
 sub today_stamp
@@ -72,6 +72,13 @@ sub stamp_to_localtime
     return timelocal( 59, 59, 23, reverse @date );
 }
 
+sub prev_stamp
+{
+    my ($stamp) = @_;
+    my $epoch = stamp_to_localtime( $stamp ) - 12 * 3600; # noon today
+    return fmt_date( $epoch - 86400 ); # noon yesterday
+}
+
 sub day_stamp
 {
     my ( $day ) = @_;
@@ -135,7 +142,7 @@ App::TimelogTxt::Utils - Utility functions for the App::TimelogTxt modules.
 
 =head1 VERSION
 
-This document describes App::TimelogTxt::Utils version 0.05
+This document describes App::TimelogTxt::Utils version 0.06
 
 =head1 SYNOPSIS
 
